/*
 * Copyright 1999-2018 Alibaba Group Holding Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.alibaba.nacos.core.notify.listener;

import com.alibaba.nacos.core.notify.Event;

/**
 * Subscribers to multiple events can be listened to
 *
 * @author <a href="mailto:liaochuntao@live.com">liaochuntao</a>
 */
@SuppressWarnings("PMD.AbstractClassShouldStartWithAbstractNamingRule")
public abstract class SmartSubscribe implements Subscribe<Event> {

	/**
	 * Determines if the processing message is acceptable
	 *
	 * @param event {@link Event}
	 * @return Determines if the processing message is acceptable
	 */
	public abstract boolean canNotify(Event event);

	@Override
	public final Class<? extends Event> subscribeType() {
		return null;
	}

	@Override
	public final boolean ignoreExpireEvent() {
		return false;
	}
}
