CREATE SCHEMA nacos AUTHORIZATION nacos;
CREATE TABLE config_info (
  id bigint NOT NULL generated by default as identity,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  tenant_id varchar(128) default '',
  app_name varchar(128),
  content CLOB,
  md5 varchar(32) DEFAULT NULL,
  gmt_create timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  gmt_modified timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  src_user varchar(128) DEFAULT NULL,
  src_ip varchar(20) DEFAULT NULL,
  c_desc varchar(256) DEFAULT NULL,
  c_use varchar(64) DEFAULT NULL,
  effect varchar(64) DEFAULT NULL,
  type varchar(64) DEFAULT NULL,
  c_schema LONG VARCHAR DEFAULT NULL,
  constraint configinfo_id_key PRIMARY KEY (id),
  constraint uk_configinfo_datagrouptenant UNIQUE (data_id, group_id, tenant_id)
);
CREATE INDEX configinfo_dataid_key_idx ON config_info(data_id);
CREATE INDEX configinfo_groupid_key_idx ON config_info(group_id);
CREATE INDEX configinfo_dataid_group_key_idx ON config_info(data_id, group_id);
CREATE TABLE his_config_info (
  id bigint NOT NULL,
  nid bigint NOT NULL generated by default as identity,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  tenant_id varchar(128) default '',
  app_name varchar(128),
  content CLOB,
  md5 varchar(32) DEFAULT NULL,
  gmt_create timestamp NOT NULL DEFAULT '2010-05-05 00:00:00.000',
  gmt_modified timestamp NOT NULL DEFAULT '2010-05-05 00:00:00.000',
  src_user varchar(128),
  src_ip varchar(20) DEFAULT NULL,
  op_type char(10) DEFAULT NULL,
  constraint hisconfiginfo_nid_key PRIMARY KEY (nid)
);
CREATE INDEX hisconfiginfo_dataid_key_idx ON his_config_info(data_id);
CREATE INDEX hisconfiginfo_gmt_create_idx ON his_config_info(gmt_create);
CREATE INDEX hisconfiginfo_gmt_modified_idx ON his_config_info(gmt_modified);
CREATE TABLE config_info_beta (
  id bigint NOT NULL generated by default as identity,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  tenant_id varchar(128) default '',
  app_name varchar(128),
  content CLOB,
  beta_ips varchar(1024),
  md5 varchar(32) DEFAULT NULL,
  gmt_create timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  gmt_modified timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  src_user varchar(128),
  src_ip varchar(20) DEFAULT NULL,
  constraint configinfobeta_id_key PRIMARY KEY (id),
  constraint uk_configinfobeta_datagrouptenant UNIQUE (data_id, group_id, tenant_id)
);
CREATE TABLE config_info_tag (
  id bigint NOT NULL generated by default as identity,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  tenant_id varchar(128) default '',
  tag_id varchar(128) NOT NULL,
  app_name varchar(128),
  content CLOB,
  md5 varchar(32) DEFAULT NULL,
  gmt_create timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  gmt_modified timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  src_user varchar(128),
  src_ip varchar(20) DEFAULT NULL,
  constraint configinfotag_id_key PRIMARY KEY (id),
  constraint uk_configinfotag_datagrouptenanttag UNIQUE (data_id, group_id, tenant_id, tag_id)
);
CREATE TABLE config_info_aggr (
  id bigint NOT NULL generated by default as identity,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  tenant_id varchar(128) default '',
  datum_id varchar(255) NOT NULL,
  app_name varchar(128),
  content CLOB,
  gmt_modified timestamp NOT NULL DEFAULT '2010-05-05 00:00:00',
  constraint configinfoaggr_id_key PRIMARY KEY (id),
  constraint uk_configinfoaggr_datagrouptenantdatum UNIQUE (data_id, group_id, tenant_id, datum_id)
);
CREATE TABLE app_list (
  id bigint NOT NULL generated by default as identity,
  app_name varchar(128) NOT NULL,
  is_dynamic_collect_disabled smallint DEFAULT 0,
  last_sub_info_collected_time timestamp DEFAULT '1970-01-01 08:00:00.0',
  sub_info_lock_owner varchar(128),
  sub_info_lock_time timestamp DEFAULT '1970-01-01 08:00:00.0',
  constraint applist_id_key PRIMARY KEY (id),
  constraint uk_appname UNIQUE (app_name)
);
CREATE TABLE app_configdata_relation_subs (
  id bigint NOT NULL generated by default as identity,
  app_name varchar(128) NOT NULL,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  gmt_modified timestamp DEFAULT '2010-05-05 00:00:00',
  constraint configdatarelationsubs_id_key PRIMARY KEY (id),
  constraint uk_app_sub_config_datagroup UNIQUE (app_name, data_id, group_id)
);
CREATE TABLE app_configdata_relation_pubs (
  id bigint NOT NULL generated by default as identity,
  app_name varchar(128) NOT NULL,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  gmt_modified timestamp DEFAULT '2010-05-05 00:00:00',
  constraint configdatarelationpubs_id_key PRIMARY KEY (id),
  constraint uk_app_pub_config_datagroup UNIQUE (app_name, data_id, group_id)
);
CREATE TABLE config_tags_relation (
  id bigint NOT NULL,
  tag_name varchar(128) NOT NULL,
  tag_type varchar(64) DEFAULT NULL,
  data_id varchar(255) NOT NULL,
  group_id varchar(128) NOT NULL,
  tenant_id varchar(128) DEFAULT '',
  nid bigint NOT NULL generated by default as identity,
  constraint config_tags_id_key PRIMARY KEY (nid),
  constraint uk_configtagrelation_configidtag UNIQUE (id, tag_name, tag_type)
);
CREATE INDEX config_tags_tenant_id_idx ON config_tags_relation(tenant_id);
CREATE TABLE group_capacity (
  id bigint NOT NULL generated by default as identity,
  group_id varchar(128) DEFAULT '',
  quota int DEFAULT 0,
  usage int DEFAULT 0,
  max_size int DEFAULT 0,
  max_aggr_count int DEFAULT 0,
  max_aggr_size int DEFAULT 0,
  max_history_count int DEFAULT 0,
  gmt_create timestamp DEFAULT '2010-05-05 00:00:00',
  gmt_modified timestamp DEFAULT '2010-05-05 00:00:00',
  constraint group_capacity_id_key PRIMARY KEY (id),
  constraint uk_group_id UNIQUE (group_id)
);
CREATE TABLE tenant_capacity (
  id bigint NOT NULL generated by default as identity,
  tenant_id varchar(128) DEFAULT '',
  quota int DEFAULT 0,
  usage int DEFAULT 0,
  max_size int DEFAULT 0,
  max_aggr_count int DEFAULT 0,
  max_aggr_size int DEFAULT 0,
  max_history_count int DEFAULT 0,
  gmt_create timestamp DEFAULT '2010-05-05 00:00:00',
  gmt_modified timestamp DEFAULT '2010-05-05 00:00:00',
  constraint tenant_capacity_id_key PRIMARY KEY (id),
  constraint uk_tenant_id UNIQUE (tenant_id)
);
CREATE TABLE tenant_info (
  id bigint NOT NULL generated by default as identity,
  kp varchar(128) NOT NULL,
  tenant_id varchar(128) DEFAULT '',
  tenant_name varchar(128) DEFAULT '',
  tenant_desc varchar(256) DEFAULT NULL,
  create_source varchar(32) DEFAULT NULL,
  gmt_create bigint NOT NULL,
  gmt_modified bigint NOT NULL,
  constraint tenant_info_id_key PRIMARY KEY (id),
  constraint uk_tenant_info_kptenantid UNIQUE (kp, tenant_id)
);
CREATE INDEX tenant_info_tenant_id_idx ON tenant_info(tenant_id);
CREATE TABLE users (
  username varchar(50) NOT NULL PRIMARY KEY,
  password varchar(500) NOT NULL,
  enabled boolean NOT NULL DEFAULT true
);
CREATE TABLE roles (
  username varchar(50) NOT NULL,
  role varchar(50) NOT NULL,
  constraint uk_username_role UNIQUE (username, role)
);
CREATE TABLE permissions (
  role varchar(50) NOT NULL,
  resource varchar(512) NOT NULL,
  action varchar(8) NOT NULL,
  constraint uk_role_permission UNIQUE (role, resource, action)
);
INSERT INTO
  users (username, password, enabled)
VALUES
  (
    'nacos',
    '$2a$10$EuWPZHzz32dJN7jexM34MOeYirDdFAZm2kuWj7VEOJhhZkDrxfvUu',
    TRUE
  );
INSERT INTO
  roles (username, role)
VALUES
  ('nacos', 'ROLE_ADMIN');
INSERT INTO
  NACOS.TENANT_INFO (
    KP,
    TENANT_ID,
    TENANT_NAME,
    TENANT_DESC,
    CREATE_SOURCE,
    GMT_CREATE,
    GMT_MODIFIED
  )
VALUES
  (
    '1',
    'tofly-dyrq',
    'tofly-dyrq',
    '基础配置',
    'nacos',
    1603853060491,
    1603853060491
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'tofly-dyrq.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'server:
	  port: 8081',
    '2020-10-28 10:53:33.082000000',
    '2020-10-28 10:53:33.082000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'tofly-getway.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'server:
    port: 1111

tofly:
  client_Id: tofly
  client_secret: tofly
  grant_type: password

eureka:
  client:
    enabled: false

tofly-base:
  ribbon:
    NFLoadBalancerRuleClassName: com.tofly.toflygetway.balance.ToflyChooseBalancerRule

spring:
  #拦截规则
  cloud:
    gateway:
      routes:
        - id: tofly-auth
          uri: lb://tofly-auth
          predicates:
            - Path=/auth/**
          filters:
            - LoginParamFilter
      globalcors:
        corsConfigurations:
          ''[/**]'':
            allowCredentials: true
            exposedHeaders: "Content-Disposition,Content-Type,Cache-Control"
            allowedHeaders: "*"
            allowedOrigins: "*"
            allowedMethods: "*"
',
    '2020-10-28 10:44:59.793000000',
    '2020-10-28 10:44:59.793000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'tofly-auth.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'server:
  port: 8999

tofly-filter:
  urls:
    - /v2/api-docs
    - /actuator/**
    - /token/**

tofly-base:
  ribbon:
    NFLoadBalancerRuleClassName: com.tofly.auth.balance.ToflyChooseBalancerRule


api:
  doc:
    title: 安全认证接口    #API文档标题
    description: 登录、退出、以及登录验证应用           #API文档说明
    author: wangjian               #作者
    version: 1.0                  #版本号


security:
  oauth2:
    resource:
      loadBalanced: true
      token-info-uri: http://tofly-auth/oauth/check_token
    client:
      client-id: tofly
      client-secret: tofly
      scope: server

spring:
  cloud:
    nacos:
      config:
        shared-dataids: public_config_public.yaml,public_config_redis.yaml
        refreshable-dataids: public_config_public.yaml,public_config_redis.yaml',
    '2020-10-28 10:45:16.431000000',
    '2020-10-28 10:45:16.431000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'tofly-base.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'server:
  port: 8010

tofly-filter:
  urls:
    - /user/info/**
    - /applog**
    - /v2/api-docs
    - /getAsciiDocs**
    - /getMarkdownDocs**
    - /log/add*
    - /swagger2word/**
    - /actuator/**
    - /ftpfiles/saveBatch
    - /projectinfo/get

api:
  doc:
    title: 权限系统管理相关接口
    description: 包括用户菜单角色部门等信息
    author: wangjian
    version: 1.0
user:
  avatar: /base/useravatar/
  logo: /base/logo/

spring:
  datasource:
    url: jdbc:oracle:thin:@tofly-db:1521/orcl
    driver-class-name: oracle.jdbc.OracleDriver
    username: tf_dyrq_sms
    password: tf_dyrq_sms
    type: com.alibaba.druid.pool.DruidDataSource
    druid:
      initial-size: 10
      min-idle: 1
      max-active: 100
      max-wait: 60000
      time-between-eviction-runsMillis: 60000
      min-evictable-idle-timeMillis: 300000
      validation-query: select 1 FROM DUAL
      test-while-idle: true
      test-on-borrow: false
      test-on-return: false
      pool-prepared-statements: true
      max-open-prepared-statements: 20
      max-pool-prepared-statement-per-connection-size: 20
      filters:
        stat:
          log-slow-sql: true
          slow-sql-millis: 5000
          merge-sql: false
        wall:
          config:
            multi-statement-allow: true
      use-global-data-source-stat: true

security:
  oauth2:
    resource:
      loadBalanced: true
      token-info-uri: http://tofly-auth/oauth/check_token
    client:
      client-id: tofly
      client-secret: tofly
      scope: server

',
    '2020-10-28 10:45:34.433000000',
    '2020-10-28 10:45:34.433000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_oracle.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'spring:
    datasource:
      url: jdbc:oracle:thin:@tofly-db:1521/orcl
      driver-class-name: oracle.jdbc.OracleDriver
      #    driver-class-name: oracle.jdbc.driver.OracleDriver
      username: tf_dyrq
      password: tf_dyrq
      type: com.alibaba.druid.pool.DruidDataSource
      druid:
        initial-size: 10
        min-idle: 1
        max-active: 100
        max-wait: 60000
        time-between-eviction-runsMillis: 60000
        min-evictable-idle-timeMillis: 300000
        validation-query: select 1 FROM DUAL
        test-while-idle: true
        test-on-borrow: false
        test-on-return: false
        pool-prepared-statements: true
        max-open-prepared-statements: 20
        max-pool-prepared-statement-per-connection-size: 20
        filters:
          stat:
            log-slow-sql: true
            slow-sql-millis: 5000
            merge-sql: false
          wall:
            config:
              multi-statement-allow: true
        #      connection-properties: druid.stat.mergeSql=true;druid.stat.slowSqlMillis=5000
        use-global-data-source-stat: true
mybatis-plus:
  type-aliases-package: com.tofly.*.entity
  mapper-locations: classpath*:/mapper/*Mapper.xml,classpath*:/customMapper/*Mapper.xml
  global-config:
    banner: false
    db-config:
      id-type: INPUT
      field-strategy: NOT_NULL
      table-underline: true
      logic-delete-value: 0 #逻辑已删除
      logic-not-delete-value: 1
      db-type: oracle
  configuration:
    map-underscore-to-camel-case: true
    call-setters-on-nulls: true
    jdbc-type-for-null: null
    log-impl: org.apache.ibatis.logging.stdout.StdOutImpl                ',
    '2020-10-28 10:45:56.065000000',
    '2020-10-28 10:45:56.065000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_redis.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'spring:
  redis:
    password:
    host: tofly-redis
    jedis:
      pool:
        max-idle: 30
        min-idle: 10
        max-active: 20
        max-wait: 10000
aa: bb',
    '2020-10-28 10:46:23.352000000',
    '2020-10-28 10:46:23.352000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_ftp.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'ftp:
  enable: true
  server: tofly-ftp
  port: 8033
  userName: ENC(tjdOntnkeceeo/aiTdGifA==)
  password: ENC(tjdOntnkeceeo/aiTdGifA==)',
    '2020-10-28 10:47:52.597000000',
    '2020-10-28 10:47:52.597000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_public.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    '# 加解密根密码
jasypt:
  encryptor:
    password: tofly #根密码

# Spring 相关
spring:
  # zipkin
  # zipkin:
  #   enabled: true
  #   base-url: http://127.0.0.1:6002
  sleuth:
    web:
      client:
        enabled: true
    sampler:
      # 默认的采样比率为0.1，不能看到所有请求数据
      # 更改采样比率为1，就能看到所有的请求数据了，但是这样会增加接口调用延迟
      probability: 1.0
  servlet:
    multipart:
      max-file-size: 100MB
      max-request-size: 100MB
  jackson:
    date-format: yyyy-MM-dd HH:mm:ss
    time-zone: GMT+8
#  boot:
#    admin:
#      client:
#        url: http://127.0.0.1:6001

# 暴露监控端点
management:
  endpoints:
    web:
      exposure:
        include: ''*''

# feign 配置
feign:
  hystrix:
    enabled: true
  okhttp:
    enabled: true
  httpclient:
    enabled: false
  client:
    config:
      default:
        connectTimeout: 10000
        readTimeout: 10000
  compression:
    request:
      enabled: true
    response:
      enabled: true

# hystrix 配置
hystrix:
  command:
    default:
      execution:
        isolation:
          strategy: SEMAPHORE
          thread:
            timeoutInMilliseconds: 60000
  shareSecurityContext: true

#请求处理的超时时间
ribbon:
  ReadTimeout: 10000
  ConnectTimeout: 10000

  #spring security 配置
security:
  oauth2:
    resource:
      loadBalanced: true
      token-info-uri: http://tofly-auth/oauth/check_token
    client:
      client-id: ENC(uRVGfvAwW6FVQJm/GC7v0A==)  #tofly
      client-secret: ENC(w5AYCtwwgd+zVwGc5AudCw==)
      scope: server

toflylog:
  serviceName: tofly-base
  apiName: /log/add',
    '2020-10-28 10:48:12.998000000',
    '2020-10-28 10:48:12.998000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_logsserver.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    'toflylog:
  serviceName: tofly-base
  apiName: /log/add',
    '2020-10-28 10:48:29.822000000',
    '2020-10-28 10:48:29.822000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_xxl_job.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    '
xxl:
  job:
    admin:
      addresses: tofly-xxl-job:8020/xxl-job-admin
    executor:
      appname: tofly-dyrq
      address: ""
      ip: ""
      port: 7010
      logpath: D:/java/jdk/xnkdjars/logs/xxl-job
      logretentiondays: 30
    accessToken: ""
	',
    '2020-10-28 10:53:33.082000000',
    '2020-10-28 10:53:33.082000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
INSERT INTO
  NACOS.CONFIG_INFO (
    DATA_ID,
    GROUP_ID,
    TENANT_ID,
    APP_NAME,
    CONTENT,
    GMT_CREATE,
    GMT_MODIFIED,
    SRC_USER,
    SRC_IP,
    C_DESC,
    C_USE,
    EFFECT,
    TYPE,
    C_SCHEMA
  )
VALUES
  (
    'public_config_activemq.yaml',
    'DEFAULT_GROUP',
    'tofly-dyrq',
    '',
    '
spring:
  activemq:
    broker-url: tcp://tofly-activemq:61616
    user: admin
    password: admin
    close-timeout: 15s   # 在考虑结束之前等待的时间
    in-memory: true      # 默认代理URL是否应该在内存中。如果指定了显式代理，则忽略此值。
    non-blocking-redelivery: false  # 是否在回滚回滚消息之前停止消息传递。这意味着当启用此命令时，消息顺序不会被保留。
    send-timeout: 0     # 等待消息发送响应的时间。设置为0等待永远。
    pool:
      enabled: true
      max-connections: 10   #连接池最大连接数
      idle-timeout: 30000   #空闲的连接过期时间，默认为30秒
#  jms:
#    pub-sub-domain: true  #默认情况下activemq提供的是queue模式，若要使用topic模式需要配置
	',
    '2020-10-28 10:53:33.082000000',
    '2020-10-28 10:53:33.082000000',
    null,
    '0:0:0:0:0:0:0:1',
    null,
    null,
    null,
    'yaml',
    null
  );
